rjust

Function rjust 

pub fn rjust<D: Dimension>(
    a: &StringArray<D>,
    width: usize,
) -> FerrayResult<StringArray<D>>
Right-justify each string in a field of the given width, padded with spaces.

If the string is already longer than width, it is returned unchanged.

Errors

Returns an error if the internal array construction fails.