Module case

Module case 

Functions

capitalize
Capitalize each string element: the first character is titlecased and the rest is lowercased (final-sigma aware), matching Python str.capitalize.
lower
Convert each string element to lowercase.
title
Title-case each string element: each word starts with a titlecased character and all remaining cased characters are lowercased, matching Python str.title / numpy.char.title.
upper
Convert each string element to uppercase.