pub fn lower<D: Dimension>(a: &StringArray<D>) -> FerrayResult<StringArray<D>>Expand description
Convert each string element to lowercase.
Errors
Returns an error if the internal array construction fails.
pub fn lower<D: Dimension>(a: &StringArray<D>) -> FerrayResult<StringArray<D>>Convert each string element to lowercase.
Returns an error if the internal array construction fails.