Module regex_ops
ferray_
strings
0.2.3
Module regex_
ops
Module Items
Functions
In crate ferray_
strings
ferray_strings
Module
regex_
ops
Functions

extract
Extract the first capture group from each string element.
match_
Test whether each string element matches the given regex pattern.