Module search

Module search 

Functions

count
Count non-overlapping occurrences of sub in each string element.
endswith
Test whether each string element ends with the given suffix.
find
Find the lowest index of sub in each string element.
replace
Replace occurrences of old with new in each string element.
startswith
Test whether each string element starts with the given prefix.