endswith

Function endswith 

pub fn endswith<D: Dimension>(
    a: &StringArray<D>,
    suffix: &str,
) -> FerrayResult<Array<bool, Ix1>>
Test whether each string element ends with the given suffix.

Returns an Array<bool> indicating the result for each element.

Errors

Returns an error if the internal array construction fails.