join_array

Function join_array 

pub fn join_array<D: Dimension>(
    sep: &str,
    a: &StringArray<D>,
) -> FerrayResult<StringArray1>
Join each string element of a StringArray using the given separator.

This variant takes a StringArray and joins all elements into a single string. Returns a 1-D StringArray with one element.

Errors

Returns an error if the internal array construction fails.