pub fn split_ragged<D: Dimension>( a: &StringArray<D>, sep: &str, ) -> FerrayResult<Vec<Vec<String>>>
Ragged-result variant of split: returns a Vec<Vec<String>> so callers that need the unpadded splits per element don’t have to strip empty padding from the 2-D result (#277).
split
Vec<Vec<String>>
Returns an error only for internal failures.