pub fn strip<D: Dimension>(
a: &StringArray<D>,
chars: Option<&str>,
) -> FerrayResult<StringArray<D>>Expand description
Strip leading and trailing characters from each string element.
If chars is None, strips whitespace. Otherwise strips any character
present in the chars string.
Errors
Returns an error if the internal array construction fails.