Module align

Module align 

Functions

center
Center each string in a field of the given width, padded with fillchar.
ljust
Left-justify each string in a field of the given width, padded with spaces.
rjust
Right-justify each string in a field of the given width, padded with spaces.
zfill
Pad each string on the left with zeros to fill the given width.