pub fn center<D: Dimension>(
a: &StringArray<D>,
width: usize,
fillchar: char,
) -> FerrayResult<StringArray<D>>Expand description
Center each string in a field of the given width, padded with fillchar.
If the string is already longer than width, it is returned unchanged.
Errors
Returns an error if the internal array construction fails.