Skip to main content Module classify Copy item path Source isalnum Return true where every character is alphanumeric and the string
is non-empty. Matches numpy.strings.isalnum. isalpha Return true where every character is alphabetic and the string is
non-empty. Matches numpy.strings.isalpha. isdigit Return true where every character is a digit and the string is
non-empty. Matches numpy.strings.isdigit. islower Return true where every character is lowercase and the string is
non-empty. Matches numpy.strings.islower. isnumeric Return true where the string could be a valid numeric literal.
Matches numpy.strings.isnumeric (simplified — checks for
ASCII digit + decimal point + sign characters). isspace Return true where every character is whitespace and the string is
non-empty. Matches numpy.strings.isspace. istitle Return true where the string is titlecased (first letter of each
word is uppercase, the rest lowercase). Matches
numpy.strings.istitle. isupper Return true where every character is uppercase and the string is
non-empty. Matches numpy.strings.isupper.