pub fn expandtabs<D: Dimension>(
a: &StringArray<D>,
tabsize: usize,
) -> FerrayResult<StringArray<D>>Expand description
Replace tab characters in each element with spaces, expanding to the given tab size on column boundaries.
Equivalent to numpy.strings.expandtabs(arr, tabsize).
Errors
Returns an error if the internal array construction fails.