pub fn match_<D: Dimension>(
a: &StringArray<D>,
pattern: &str,
) -> FerrayResult<Array<bool, Ix1>>Expand description
Test whether each string element matches the given regex pattern.
Returns an Array<bool> where each element indicates whether the
corresponding string contains a match for the pattern.
Errors
Returns FerrayError::InvalidValue if the regex pattern is invalid.
Returns an error if the internal array construction fails.