Module search

Module search 

Functions

count
Count non-overlapping occurrences of sub in each string element.
endswith
Test whether each string element ends with the given suffix.
find
Find the lowest index of sub in each string element.
index
Find the lowest character index of sub in each string element, raising when any element does not contain sub.
replace
Replace occurrences of old with new in each string element.
rfind
Find the highest character index of sub in each string element.
rindex
Find the highest character index of sub in each string element, raising when any element does not contain sub.
startswith
Test whether each string element starts with the given prefix.