pub fn find<D: Dimension>(
a: &StringArray<D>,
sub: &str,
) -> FerrayResult<Array<i64, Ix1>>Expand description
Find the lowest index of sub in each string element.
Returns an Array<i64> where each element is the index of the first
occurrence of sub, or -1 if not found.
Errors
Returns an error if the internal array construction fails.