pub fn replace<D: Dimension>(
a: &StringArray<D>,
old: &str,
new: &str,
max_count: Option<usize>,
) -> FerrayResult<StringArray<D>>Expand description
Replace occurrences of old with new in each string element.
If max_count is Some(n), only the first n occurrences are replaced.
If None, all occurrences are replaced.
Errors
Returns an error if the internal array construction fails.