pub fn startswith<D: Dimension>(
a: &StringArray<D>,
prefix: &str,
) -> FerrayResult<Array<bool, Ix1>>Expand description
Test whether each string element starts with the given prefix.
Returns an Array<bool> indicating the result for each element.
Errors
Returns an error if the internal array construction fails.