Module split_join

Module split_join 

Functions

join
Join a collection of string vectors using the given separator.
join_array
Join each string element of a StringArray using the given separator.
rsplit
Right-to-left counterpart of split (#515).
split
Split each string element by the given separator.
split_ragged
Ragged-result variant of split: returns a Vec<Vec<String>> so callers that need the unpadded splits per element don’t have to strip empty padding from the 2-D result (#277).
splitlines
Split each element on universal newlines (#515). Equivalent to numpy.strings.splitlines.