join

Function join 

pub fn join(sep: &str, items: &[Vec<String>]) -> FerrayResult<StringArray1>
Join a collection of string vectors using the given separator.

Each element in the input is a Vec<String> which is joined into a single string. Returns a 1-D StringArray.

Errors

Returns an error if the internal array construction fails.